@@ -50,7 +50,7 @@ def normalize_adjustment(feature_values):
 
 def get_sample_times(bucket,measurment_occaisons,feature_values,abnormal_ratio,measure_max,sampling_function=None):
     if bucket == "equal":
-        return(np.linspace(0,((1-abnormal_ratio)+abnormal_ratio*(measurment_occaisons/measure_max)),measurment_occaisons))
+        return(np.linspace(0,((0.9999-abnormal_ratio)+abnormal_ratio*(measurment_occaisons/measure_max)),measurment_occaisons))
     elif bucket == "random":
         return(np.random.uniform(low=0.0, high=((1-abnormal_ratio)+abnormal_ratio*(measurment_occaisons/measure_max)), size=measurment_occaisons))
     elif bucket == "not-random":
@@ -261,7 +261,7 @@ class patient:
         if (sampling_bucket=="not-random") | (sampling_bucket=="custom-feature-values"):
             total_length=len(features)+len(extraneous_variables)
             x_cov_matrix=np.ones((total_length,total_length))
-            np.fill_diagonal(x_cov_matrix,colinearity[2])
+            np.fill_diagonal(x_cov_matrix,np.abs(colinearity[2]))
             x=np.random.multivariate_normal(tuple(np.ones(total_length)*b_factor), x_cov_matrix, self.measure_count)
             index=0
             for feature in features:
